* GENERAL INFO
	* Project: National Versus Ethnic Identity in Africa
	* Created by: Amanda Robinson
	* Date created: July 2013

* DO FILE INFO
	* This .do file runs the models included in "National vs. Ethnic Identification in Africa" in World Politics.

	clear		
	set more off
********************************************************************************************************************* 

use "Robinson2014_Nationalism.dta"
*** mixed-model analyses ***


*null model
xtmixed national || country: || q79: , variance
xtmrho

*main models
eststo m1:xtmixed national gender formemp edu indurb lethsize part30 preg lngdp05 ethfrac colbrit anticolwar || country: || q79: , variance 
xtmrho
eststo m2:xtmixed national gender formemp edu indurb lethsize part30 preg lngdp05 ethfrac colbrit anticolwar if country~=15 || country: || q79: , variance 
xtmrho


xtile income=lngdp, n(4)
adjust gender formemp edu indurb lethsize part30 preg ethfrac colbrit anticolwar, by(income)

recode edu (0/4=0)(5/9=1), gen(hs)
adjust gender lethsize part30 preg lngdp05 ethfrac colbrit anticolwar, by(edu indurb formemp)


*robust to different specifications of the DV
	*diff DV, idrank
xtmixed idrank gender formemp edu indurb lethsize part30 preg lngdp05 ethfrac colbrit anticolwar || country: || q79: , variance 
xtmixed idrank gender formemp edu indurb lethsize part30 preg lngdp05 ethfrac colbrit anticolwar if country~=15  || country: || q79:  , variance 
meoprobit idrank gender formemp edu indurb lethsize part30 preg lngdp05 ethfrac colbrit anticolwar || country: || q79: 
meoprobit idrank gender formemp edu indurb lethsize part30 preg lngdp05 ethfrac colbrit anticolwar if country~=15  || country: || q79: 

*robust to 1999 GDP
xtmixed national gender formemp edu indurb lethsize part30 preg lgdpen ethfrac colbrit anticolwar || country: || q79: , variance 
xtmixed national gender formemp edu indurb lethsize part30 preg lgdpen ethfrac colbrit anticolwar if country~=15 || country: || q79: , variance

*with ethnic power relations data
xtmixed national gender formemp edu indurb lethsize part30 polmob lngdp05 ethfrac colbrit anticolwar || country: || q79: , variance
xtmixed national gender formemp edu indurb lethsize part30 polmob lngdp05 ethfrac colbrit anticolwar || country: || q79: if country~=15, variance

*diff thresholds for ethnic group partition
summ percentout part1 part10 part20 part30 part40 part50
foreach x in percentout part1 part10 part20 part30 part40 part50 {
xtmixed national gender formemp edu indurb lethsize `x' preg lngdp05 ethfrac colbrit anticolwar || country: || q79: , variance 
xtmixed national gender formemp edu indurb lethsize `x' preg lngdp05 ethfrac colbrit anticolwar if country~=15 || country: || q79: , variance 
}

*diff measures of ethnic fractionalization
xtmixed national gender formemp edu indurb lethsize part30 preg lngdp05 plural colbrit anticolwar || country: || q79: , variance
xtmixed national gender formemp edu indurb lethsize part30 preg lngdp05 plural colbrit anticolwar if country~=15  || country: || q79: , variance
xtmixed national gender formemp edu indurb lethsize part30 preg lngdp05 cdiv colbrit anticolwar || country: || q79: , variance
xtmixed national gender formemp edu indurb lethsize part30 preg lngdp05 cdiv colbrit anticolwar if country~=15  || country: || q79: , variance


*code S. Africa and Namibia as having had an anti-colonial war
recode anticolwar (0=1) if safrica==1
recode anticolwar (0=1) if namibia==1	
xtmixed national gender formemp edu indurb lethsize part30 preg lngdp05 ethfrac colbrit anticolwar || country: || q79: , variance
xtmixed national gender formemp edu indurb lethsize part30 preg lngdp05 ethfrac colbrit anticolwar if country~=15  || country: || q79: , variance
recode anticolwar (1=0) if safrica==1
recode anticolwar (1=0) if namibia==1	


*robust to logit specification (presented as odds ratios)
xtmelogit national gender formemp edu indurb lethsize part30 preg lngdp05 ethfrac colbrit anticolwar || country: || q79: , variance or
xtmrho
xtmelogit national gender formemp edu indurb lethsize part30 preg lngdp05 ethfrac colbrit anticolwar if country~=15  || country: || q79: , variance or
xtmrho

*robust to non-heirarchical modelling
	*individual with country/ethnic group fixed effects
areg national gender formemp edu indurb, abs(country)
areg national gender formemp edu indurb if country~=15, abs(country)
areg national gender formemp edu indurb, abs(q79)
areg national gender formemp edu indurb if country ~=15, abs(q79)


	*ethnic group variable: ethnic group level with country fixed effects, with samples greater than n=10 for each ethnic group
tempfile full 
save `full'
collapse national lethsize part30 preg country (count) age, by(q79)
areg national lethsize part30 preg if age>10, abs(country)
areg national lethsize part30 preg if age>10 & country~=15, abs(country)
use `full', clear


	*country variables: country level
	
collapse national lngdp05 ethfrac plural colbrit anticolwar, by(country)
reg national lngdp05 ethfrac colbrit anticolwar
rvfplot, yline(0) mlabel(country)
predict resid, residuals
predict sresid, rstandard
qnorm sresid, mlabel(country)
dfbeta lngdp05 ethfrac colbrit anticolwar
foreach x in 1 2 3 4 {
replace _dfbeta_`x'=abs(_dfbeta_`x')
list country _dfbeta_`x' if _dfbeta_`x' > 2/sqrt(16), divider
}
latabstat  _dfbeta_1 _dfbeta_2 _dfbeta_3 _dfbeta_4, by(country)  f(%9.2fc)

reg national lngdp05 ethfrac colbrit anticolwar if country~=15, vce(cluster country)
use `full', clear



*robust to dropping one country at a time
foreach x in 1 2 4 5 6 7 8 9 10 11 12 13 14 15 16 17 {
xtmixed national gender formemp edu indurb lethsize part30 preg lngdp05 ethfrac colbrit anticolwar if country~=`x' || country: || q79:, variance 
}
	
*add ethnic group level measures of "modernization"
eststo m3: xtmixed national lngdp05 ethfrac colbrit anticolwar lethsize part30 preg ethedu ethformemp ethindurb  formemp edu indurb gender || country: || q79: , variance 
eststo m4: xtmixed national lngdp05 ethfrac colbrit anticolwar lethsize part30 preg ethedu ethformemp ethindurb  formemp edu indurb gender  if country~=15 || country: || q79: , variance 
eststo m1: xtmixed national lngdp05 ethfrac colbrit anticolwar lethsize part30 preg ethgroupstat formemp edu indurb gender || country: || q79: , variance
eststo m2: xtmixed national lngdp05 ethfrac colbrit anticolwar lethsize part30 preg ethgroupstat  formemp edu indurb gender if country~=15 || country: || q79: , variance 





*add group size squared term
xtmixed national gender formemp edu indurb ethsize ethsize2 part30 preg lngdp05 ethfrac colbrit anticolwar || country: || q79: , variance 
xtmixed national gender formemp edu indurb ethsize ethsize2 part30 preg lngdp05 ethfrac colbrit anticolwar if country~=15 || country: || q79: , variance 
	
*ethnic group currently in power?
	*control, and interacted with group-level variables
foreach x in lethsize part30 preg {
gen ethp_`x'=ethpower*`x'
gen inp_`x'=inpower*`x'
}
	*coethnic head of state
eststo m1: xtmixed national gender formemp edu indurb ethpower lethsize part30 preg lngdp05 ethfrac colbrit anticolwar || country: || q79: , variance
eststo m2:xtmixed national gender formemp edu indurb ethpower lethsize part30 preg lngdp05 ethfrac colbrit anticolwar || country: || q79: if country~=15, variance
eststo m3:xtmixed national gender formemp edu indurb ethpower  lethsize part30 preg ethp_lethsize ethp_part30 ethp_preg lngdp05 ethfrac colbrit anticolwar || country: || q79: , variance
eststo m4:xtmixed national gender formemp edu indurb ethpower lethsize part30 preg ethp_lethsize ethp_part30 ethp_preg lngdp05 ethfrac colbrit anticolwar|| country: || q79: if country~=15, variance
estout m1 m2 m3 m4, style(tex) cells(b(star fmt(3)) se(par)) starlevels(\sym{*} 0.10 \sym{**} 0.05 \sym{***} 0.01) label
	*EPR inpower
eststo m1:xtmixed national gender formemp edu indurb inpower lethsize part30 preg lngdp05 ethfrac colbrit anticolwar || country: || q79: , variance
eststo m2:xtmixed national gender formemp edu indurb inpower lethsize part30 preg lngdp05 ethfrac colbrit anticolwar || country: || q79: if country~=15, variance
eststo m3:xtmixed national gender formemp edu indurb inpower lethsize part30 preg inp_lethsize inp_part30 inp_preg lngdp05 ethfrac colbrit anticolwar || country: || q79: , variance
eststo m4:xtmixed national gender formemp edu indurb inpower lethsize part30 preg inp_lethsize inp_part30 inp_preg lngdp05 ethfrac colbrit anticolwar || country: || q79: if country~=15, variance

*social desirability bias	
	*presence of others - exclude when others were present, or influenced by others
ttest national, by(others)
eststo m1:xtmixed national others gender formemp edu indurb lethsize part30 preg lngdp05 ethfrac colbrit anticolwar  || country: || q79: , variance
eststo m2:xtmixed national others gender formemp edu indurb lethsize part30 preg lngdp05 ethfrac colbrit anticolwar  if country~=15 || country: || q79: , variance

	*include interviewer coethnicity variables (control for, and split sample)
eststo m3:xtmixed national coeth gender formemp edu indurb lethsize part30 preg lngdp05 ethfrac colbrit anticolwar  || country: || q79: , variance 
eststo m4:xtmixed national coeth gender formemp edu indurb lethsize part30 preg lngdp05 ethfrac colbrit anticolwar if country~=15 || country: || q79: , variance 

foreach x in formemp edu indurb {
gen o_`x'=others*`x'
gen c_`x'=coeth*`x'
}
xtmixed national others gender formemp edu indurb o_formemp o_edu o_indurb lethsize part30 preg lngdp05 ethfrac colbrit anticolwar  || country: || q79: , variance
xtmixed national others gender formemp edu indurb o_formemp o_edu o_indurb lethsize part30 preg lngdp05 ethfrac colbrit anticolwar  if country~=15 || country: || q79: , variance
xtmixed national coeth gender formemp edu indurb c_formemp c_edu c_indurb lethsize part30 preg lngdp05 ethfrac colbrit anticolwar  || country: || q79: , variance
xtmixed national coeth gender formemp edu indurb c_formemp c_edu c_indurb lethsize part30 preg lngdp05 ethfrac colbrit anticolwar  if country~=15 || country: || q79: , variance


	*include election timing
xtmixed national gender formemp edu indurb lethsize part30 preg lngdp05 ethfrac colbrit anticolwar eleccomp elecprox elecint || country: || q79: , variance
xtmixed national gender formemp edu indurb lethsize part30 preg lngdp05 ethfrac colbrit anticolwar eleccomp elecprox elecint if country~=15  || country: || q79: , variance





